[evolvis-commits] r17786: tarent-config pending merges:↵ Roland Mas 2011-11-15 [#1763] update comments to show what datatype=5 is↵ Roland Mas 2011-11-15 begin working on [#1073] Funktionsreferenz-Tracker [#1763]↵ Roland Mas 2011-11-10 Allow uploading *.GraphML to MediaWiki ⇒ disallow MIME type check↵ Roland Mas 2011-11-10 [TTID# 1110114] Implement [#824] Standard configuration for Tracker

mirabilos at evolvis.org mirabilos at evolvis.org
Tue Dec 6 20:26:53 CET 2011


Author: mirabilos
Date: 2011-12-06 20:26:53 +0100 (Tue, 06 Dec 2011)
New Revision: 17786

Modified:
   trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactType.class.php
   trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactTypes.class.php
   trunk/gforge_base/evolvisforge-5.1/src/common/tracker/artifact_type_definitions.php
   trunk/gforge_base/evolvisforge-5.1/src/plugins/mediawiki/www/LocalSettings.php
Log:
tarent-config pending merges:
  Roland Mas 2011-11-15 [#1763] update comments to show what datatype=5 is
    Roland Mas 2011-11-15 begin working on [#1073] Funktionsreferenz-Tracker [#1763]
    Roland Mas 2011-11-10 Allow uploading *.GraphML to MediaWiki ⇒ disallow MIME type check
    Roland Mas 2011-11-10 [TTID# 1110114] Implement [#824] Standard configuration for Tracker


Modified: trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactType.class.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactTypes.class.php	2011-12-06 19:26:49 UTC (rev 17785)
+++ trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactTypes.class.php	2011-12-06 19:26:53 UTC (rev 17786)
@@ -5,6 +5,8 @@
  * Copyright 1999-2001, VA Linux Systems, Inc.
  * Copyright 2002-2004, GForge, LLC
  * Copyright 2009, Roland Mas
+ * Copyright © 2011
+ *	Thorsten Glaser <t.glaser at tarent.de>
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -89,7 +91,7 @@
 			//
 			//	Create a tracker
 			//
-			if (!$at->create($trk[0], $trk[1], $trk[2], $trk[3], $trk[4], $trk[5], $trk[6], $trk[7], $trk[8], $trk[9], $trk[10])) {
+			if (!$at->create($trk[0], $trk[1], $trk[2], $trk[3], $trk[4], $trk[5], $trk[6], $trk[7], $trk[8], $trk[9], $trk[10], util_ifsetor($trk[12], ""))) {
 				$this->setError('Error Creating Tracker: '.$at->getErrorMessage());
 				db_rollback();
 				return false;

Modified: trunk/gforge_base/evolvisforge-5.1/src/common/tracker/artifact_type_definitions.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/common/tracker/artifact_type_definitions.php	2011-12-06 19:26:49 UTC (rev 17785)
+++ trunk/gforge_base/evolvisforge-5.1/src/common/tracker/artifact_type_definitions.php	2011-12-06 19:26:53 UTC (rev 17786)
@@ -3,6 +3,8 @@
  * FusionForge trackers
  *
  * Copyright 2005, GForge, LLC
+ * Copyright © 2011
+ *	Thorsten Glaser <t.glaser at tarent.de>
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -24,59 +26,165 @@
 //	Here is where you define different sets of default elements
 //
 
-$machines=array('All','DEC','HP','Macintosh','PC','SGI','Sun','Other');
+$oss=array('All',
+	/* Desktop Microsoft */
+	'Windows 3.1',
+	'Windows 95',
+	'Windows 98',
+	'Windows ME',
+	'Windows 2000',
+	'Windows NT',
+	'Windows XP',
+	'Windows Server 2003',
+	'Windows Server 2008',
+	'Windows 7',
+	'Windows 8',
+	/* Unix for Windows */
+	'Cygwin',
+	'Interix/SFU/SUA',
+	'MinGW32',
+	'PW32',
+	'AT&T UWIN',
+	/* Free WinAPI */
+	'ReactOS',
 
-$products=array('Software A');
+	/* Desktop Apple */
+	'Mac System 7',
+	'Mac System 7.5',
+	'Mac System 7.6.1',
+	'Mac System 8.0',
+	'Mac System 8.5',
+	'Mac System 8.6',
+	'Mac System 9.x',
+	'MacOS X',
+	'NeXTstep',
 
-$oss=array('All',
-'Windows 3.1',
-'Windows 95',
-'Windows 98',
-'Windows ME',
-'Windows 2000',
-'Windows NT',
-'Windows XP',
-'Windows Server 2003',
-'Mac System 7',
-'Mac System 7.5',
-'Mac System 7.6.1',
-'Mac System 8.0',
-'Mac System 8.5',
-'Mac System 8.6',
-'Mac System 9.x',
-'MacOS X',
-'Linux',
-'BSDI',
-'FreeBSD',
-'NetBSD',
-'OpenBSD',
-'AIX',
-'BeOS',
-'HP-UX',
-'IRIX',
-'Neutrino',
-'OpenVMS',
-'OS/2',
-'OSF/1',
-'Solaris',
-'SunOS',
-'other');
+	/* Mostly Unix */
+	'Linux',
+	'BSDi BSD/OS',
+	'DragonFly BSD',
+	'FreeBSD',
+	'MidnightBSD',
+	'MirBSD',
+	'NetBSD',
+	'OpenBSD',
 
-$components=array('Cog A','Cog B');
+	/* Old or not quite Unix */
+	'AIX',
+	'HP-UX',
+	'Hurd',
+	'IRIX',
+	'Minix',
+	'QNX/Neutrino',
+	'Solaris',
+	'SunOS',
+	'Tru64 (OSF/1)',
 
-$versions=array('v1.0','v1.1');
+	/* Less Unix */
+	'BeOS',
+	'Haiku',
+	'Inferno',
+	'Plan 9',
+	'Syllable Desktop',
 
-$severities=array('blocker',
-'critical',
-'major',
-'normal',
-'minor',
-'trivial',
-'enhancement');
+	/* Not Unix but of interest */
+	'Novell Netware',
+	'Singularity (MS Research)',
+	'OpenVMS',
+	'OS/2',
 
-$patch_ress=array('Accepted','Rejected','Out of Date','Awaiting Response');
-$bug_ress=array('Accepted As Bug','Fixed','Won\'t Fix','Invalid','Awaiting Response','Works For Me');
+	/* Mobile */
+	'Android',
+	'Apple Newton',
+	'EPOC32 (Psion)',
+	'Maemo',
+	'MeeGo',
+	'Symbian',
+	'Windows CE',
+	'Windows Mobile',
+	'Windows Phone 7',
+	'iPhoneOS',
 
+	/* Embedded or Real-Time */
+	'brickOS',
+	'leJOS',
+	'*WRT/ADK (Embedded Linux)',
+	'µClinux',
+	'eCos',
+	'Contiki',
+	'LynxOS',
+	'MenuetOS',
+	'RTEMS',
+	'VxWorks',
+
+	/* DOS */
+	'DR DOS / Caldera/Novell',
+	'FreeDOS',
+	'MS-DOS',
+	'PTS-DOS',
+	'DOSplus',
+	'DOS with GEM',
+
+	/* Old Unix */
+	'A/UX',
+	'BS2000/OSD',
+	'DomainOS / Aegis',
+	'SCO OpenServer/Unixware',
+	'SINIX',
+	'DEC ULTRIX',
+	'Xenix',
+	'zOS (OS/390)',
+
+	/* Obscure */
+	'Cisco IOS',
+	'JunOS',
+	'Oberon',
+	'Acorn RISC OS',
+	'AmigaOS (Classic)',
+	'AmigaOS 4',
+	'MorphOS',
+	'Atari TOS',
+	'Atari MultiTOS',
+	'FreeMiNT',
+	'Atari GEM',
+	'Multics',
+	'Amoeba',
+	'SkyOS',
+	'GEOS/Geoworks Ensemble',
+	'CP/M',
+	'CP/M-86',
+	'TRS-DOS (Tandy)',
+	'TSX-32',
+
+	'other'
+);
+
+$severities = array(
+	'blocker',
+	'critical',
+	'major',
+	'normal',
+	'minor',
+	'trivial',
+	'enhancement'
+);
+
+$resolutions = array(
+	'Accepted As Bug',
+	'Fixed',
+	'Won\'t Fix',
+	'Invalid',
+	'Awaiting Response',
+	'Works for me',
+	'Duplicate',
+	'Reopen',
+	'New',
+	'Spec out of Date',
+	'PM-Verified',
+	'QA-Verified',
+);
+
+
 //
 //	Here is where you combine the arrays of elements into
 //	field definitions, including titles, types, and attributes
@@ -84,17 +192,13 @@
 
 //NAME, TYPE, ATTR1, ATTR2, REQUIRED, SOURCE_ARRAY
 
-$hardware=array('Hardware',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0, $machines);
-$product=array('Product',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$products);
 $os=array('Operating System',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$oss);
-$component=array('Component',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$components);
-$version=array('Version',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$versions);
-$severity=array('Severity',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$severities);
 $url=array('URL',ARTIFACT_EXTRAFIELDTYPE_TEXT,40,100,0,array());
-
-$patchres=array('Resolution',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$patch_ress);
-$bugres=array('Resolution',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$bug_ress);
-
+$component=array('Component',ARTIFACT_EXTRAFIELDTYPE_TEXT,40,100,0,array());
+$browser=array('Browser',ARTIFACT_EXTRAFIELDTYPE_TEXT,40,100,0,array());
+$verfound=array('Version Found',ARTIFACT_EXTRAFIELDTYPE_TEXT,20,64,0,array());
+$verfixed=array('Version Fixed',ARTIFACT_EXTRAFIELDTYPE_TEXT,20,64,0,array());
+$resolution=array('Resolution',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$resolutions);
 $severity=array('Severity',ARTIFACT_EXTRAFIELDTYPE_SELECT,0,0,0,$severities);
 
 //
@@ -105,29 +209,160 @@
 /*
 NAME DESCRIPTION, $is_public,$allow_anon,$email_all,$email_address,
 $due_period,$use_resolution,$submit_instructions,$browse_instructions,
-$datatype=0,$fields
+$datatype=0,$fields,$renderer=""
 */
 
-$trackers[]=array('Bugs','Bug Tracking System',1,0,'','',30,0,'','',1, array($hardware, $product, $os, $component, $version, $severity, $bugres, $url));
+$evolvis_fields = array(
+	$os,
+	$url,
+	$component,
+	$browser,
+	$verfound,
+	$verfixed,
+	$resolution,
+	$severity,
+);
+$evolvis_renderer = '
+	<!-- Start Extra Fields Rendering (Evolvis Template: Bugs) -->
+	<!-- COLUMN NAMES MUST BE PRESERVED EXACTLY, INCLUDING CASE! -->
+	<tr>
+		<td width="50%" valign="top"><strong>Severity:<br /></strong><!--Severity--></td>
+		<td width="50%" valign="top"><strong>Resolution:<br /></strong><!--Resolution--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>Operating System:<br /></strong><!--Operating System--></td>
+		<td width="50%" valign="top"><strong>Browser</strong>:<br /><!--Browser--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>URL</strong>:<br /><!--URL--></td>
+		<td width="50%" valign="top"><strong>Component</strong>:<br /><!--Component--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>Version Found</strong>:<br /><!--Version Found--></td>
+		<td width="50%" valign="top"><strong>Version Fixed</strong>:<br /><!--Version Fixed--></td>
+	</tr>
+	<!-- End Extra Fields Rendering (Evolvis Template) -->
+';
 
-$trackers[]=array('Support','Tech Support Tracking System',1,0,'','',30,0,'','',2, array($hardware, $product, $os, $component, $version, $severity, $url));
+$trackers[]=array('Bugs','Bug Tracking System',1,0,'','',30,0,'','',1, $evolvis_fields, $evolvis_renderer);
 
-$trackers[]=array('Patches','Patch Tracking System',1,0,'','',30,0,'','',3, array($component, $version, $patchres));
+$trackers[]=array('Support','Tech Support Tracking System',1,0,'','',30,0,'','',2, $evolvis_fields, $evolvis_renderer);
 
-$trackers[]=array('Feature Requests','Feature Request Tracking System',1,0,'','',30,0,'','',4, array($product, $os, $component));
+$trackers[]=array('Patches','Patch Tracking System',1,0,'','',30,0,'','',3,
+	array($component, $verfound, $verfixed, $resolution, $severity, $url), '
+	<!-- Start Extra Fields Rendering (Evolvis Template: Patches) -->
+	<!-- COLUMN NAMES MUST BE PRESERVED EXACTLY, INCLUDING CASE! -->
+	<tr>
+		<td width="50%" valign="top"><strong>Severity:<br /></strong><!--Severity--></td>
+		<td width="50%" valign="top"><strong>Resolution:<br /></strong><!--Resolution--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>URL</strong>:<br /><!--URL--></td>
+		<td width="50%" valign="top"><strong>Component</strong>:<br /><!--Component--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>Version Found</strong>:<br /><!--Version Found--></td>
+		<td width="50%" valign="top"><strong>Version Fixed</strong>:<br /><!--Version Fixed--></td>
+	</tr>
+	<!-- End Extra Fields Rendering (Evolvis Template) -->
+');
 
-//This allows you to specify a custom status with given status_id.
-//e.g. The following allows for open and closed custom states to be defined for new trackers.
+$trackers[]=array('Feature Requests','Feature Request Tracking System',1,0,'','',30,0,'','',4,
+	array($url, $component, $browser, $os), '
+	<!-- Start Extra Fields Rendering (Evolvis Template: FRs) -->
+	<!-- COLUMN NAMES MUST BE PRESERVED EXACTLY, INCLUDING CASE! -->
+	<tr>
+		<td width="50%" valign="top"><strong>Operating System:<br /></strong><!--Operating System--></td>
+		<td width="50%" valign="top"><strong>Browser</strong>:<br /><!--Browser--></td>
+	</tr>
+	<tr>
+		<td width="50%" valign="top"><strong>URL</strong>:<br /><!--URL--></td>
+		<td width="50%" valign="top"><strong>Component</strong>:<br /><!--Component--></td>
+	</tr>
+	<!-- End Extra Fields Rendering (Evolvis Template) -->
+');
 
-/*$custom_statuses=array(
-array('Duplicate',2),
-array('Unreproducable',1),
-array('Verified',1),
-array('Needs Test',1),
-array('Needs Fix',1));
 
-$custom_status=array('Status',ARTIFACT_EXTRAFIELDTYPE_STATUS,0,0,1,$custom_statuses);*/
+/* Funktionsreferenz: https://evolvis.org/tracker/t_follow.php/1073 */
 
+$trackers[] = array('Funktionsreferenz',
+    'Funktionsreferenz (vom PM aus Kundenanforderungen erstellt)',
+    1, 0, 0, '', 30, 0, '', '', 5, array(
+	$url,
+	array('Kategorie/Komponente', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array()),
+	array('Meilenstein', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array()),
+	array('Fortschritt', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array(
+		'0%',
+		'10%',
+		'20%',
+		'30%',
+		'40%',
+		'50%',
+		'60%',
+		'70%',
+		'80%',
+		'90%',
+		'100% (SWE)',
+		'100% (SWE + QS)',
+	    )),
+	array('Anforderungstyp', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array(
+		'intern',
+		'Angebot',
+		'Feature Request',
+		'Change Request',
+	    )),
+	array('Zielversion', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array()),
+	array('Abschlußsprint', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array()),
+	array('Funktionsgruppe', ARTIFACT_EXTRAFIELDTYPE_SELECT, 0, 0, 0, array()),
+	array('Freigabe', ARTIFACT_EXTRAFIELDTYPE_CHECKBOX, 0, 0, 0, array(
+		'zum Testen',
+		'für Kunden',
+	    )),
+	array('Kundenwert', ARTIFACT_EXTRAFIELDTYPE_TEXT, 3, 3, 0, array()),
+	array('Komplexität', ARTIFACT_EXTRAFIELDTYPE_TEXT, 20, 20, 0, array()),
+	array('Spezifikationsreferenz', ARTIFACT_EXTRAFIELDTYPE_TEXT, 20, 20, 0, array()),
+	array('Status', ARTIFACT_EXTRAFIELDTYPE_STATUS, 0, 0, 1, array(
+		array('-', 2),
+		array('vorhanden', 2),
+		array('geplant', 1),
+		array('in Arbeit', 1),
+		array('in QS', 1),
+		array('fertiggestellt', 1),
+		array('zurückgestellt', 1),
+		array('Rückfrage', 1),
+		array('ausgeliefert', 2),
+		array('siehe Bemerkung', 1),
+		array('abgenommen', 2),
+		array('gelöscht', 3),
+	    )),
+    ), '
+	<!-- Start Extra Fields Rendering (Evolvis Template: Funktionsreferenz) -->
+	<!-- COLUMN NAMES MUST BE PRESERVED EXACTLY, INCLUDING CASE! -->
+	<tr>
+		<td width="50%" valign="top"><strong>Anforderungstyp:<br /></strong><!--Anforderungstyp--></td>
+		<td width="50%" valign="top"><strong>Spezifikationsreferenz</strong>:<br /><!--Spezifikationsreferenz--></td>
+	</tr><tr>
+		<td width="50%" valign="top"><strong>Kundenwert</strong>:<br /><!--Kundenwert--></td>
+		<td width="50%" valign="top"><strong>Zielversion:<br /></strong><!--Zielversion--></td>
+	</tr><tr>
+		<td width="50%" valign="top"><strong>Komplexität</strong>:<br /><!--Komplexität--></td>
+		<td width="50%" valign="top"><strong>Meilenstein:<br /></strong><!--Meilenstein--></td>
+	</tr><tr>
+		<td width="50%" valign="top"><strong>Kategorie/Komponente:<br /></strong><!--Kategorie/Komponente--></td>
+		<td width="50%" valign="top"><strong>Abschlußsprint:<br /></strong><!--Abschlußsprint--></td>
+	</tr><tr>
+		<td width="50%" valign="top"><strong>Funktionsgruppe:<br /></strong><!--Funktionsgruppe--></td>
+		<td width="50%" valign="top"><strong>Fortschritt:<br /></strong><!--Fortschritt--></td>
+	</tr><tr>
+		<td width="50%" valign="top"><table>
+			<tr><td valign="top"><strong>Status</strong>:</td><td><!--Status--></td></tr>
+			<tr><td valign="bottom"><strong>URL</strong>:</td><td><!--URL--></td></tr>
+		</table></td>
+		<td width="50%" valign="top"><strong>Freigabe:<br /></strong><!--Freigabe--></td>
+	</tr>
+	<!-- End Extra Fields Rendering (Evolvis Template) -->
+');
+
 // Local Variables:
 // mode: php
 // c-file-style: "bsd"

Modified: trunk/gforge_base/evolvisforge-5.1/src/plugins/mediawiki/www/LocalSettings.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/plugins/mediawiki/www/LocalSettings.php	2011-12-06 19:26:49 UTC (rev 17785)
+++ trunk/gforge_base/evolvisforge-5.1/src/plugins/mediawiki/www/LocalSettings.php	2011-12-06 19:26:53 UTC (rev 17786)
@@ -1,6 +1,8 @@
 <?php
 /* 
- * Copyright (C) 2010 Roland Mas, Olaf Lenz
+ * Copyright (C) 2010-2011 Roland Mas
+ * Copyright (C) 2010-2011 Thorsten Glaser
+ * Copyright (C) 2010 Olaf Lenz
  *
  * This file is part of FusionForge.
  *
@@ -88,6 +90,7 @@
 $wgMemCachedServers = array();
 
 $wgEnableUploads = forge_get_config('enable_uploads', 'mediawiki');
+$wgVerifyMimeType = false;
 $wgUploadDirectory = "$project_dir/images";
 $wgUseImageMagick = true;
 $wgImageMagickConvertCommand = "/usr/bin/convert";



More information about the evolvis-commits mailing list
--- trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactType.class.php	2011-12-06 19:26:49 UTC (rev 17785)
+++ trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactType.class.php	2011-12-06 19:26:53 UTC (rev 17786)
@@ -6,6 +6,8 @@
  * Copyright 2002-2004, GForge, LLC
  * Copyright 2009, Roland Mas
  * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
+ * Copyright © 2011
+ *	Thorsten Glaser <t.glaser at tarent.de>
  *
  * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
@@ -28,10 +30,10 @@
 
 	/**
 	* Gets an ArtifactType object from the artifact type id
-	* 
+	*
 	* @param artType_id	the ArtifactType id
 	* @param res	the DB handle if passed in (optional)
-	* @return	the ArtifactType object	
+	* @return	the ArtifactType object
 	*/
 	function &artifactType_get_object($artType_id,$res=false) {
 		global $ARTIFACTTYPE_OBJ;
@@ -51,7 +53,7 @@
 			}
 		}
 		return $ARTIFACTTYPE_OBJ["_".$artType_id."_"];
-	}	
+	}
 
 function artifacttype_get_groupid ($artifact_type_id) {
 	global $ARTIFACTTYPE_OBJ;
@@ -90,7 +92,7 @@
 	 * @var		array	extra_field
 	 */
 	var $extra_field;
-	
+
 	/**
 	 * Technicians db resource ID.
 	 *
@@ -181,19 +183,20 @@
 	 *
 	 *	@param	string	The type name.
 	 *	@param	string	The type description.
-	 *  @param  bool	(1) true (0) false - viewable by general public.
-	 *  @param  bool	(1) true (0) false - whether non-logged-in users can submit.
+	 *	@param  bool	(1) true (0) false - viewable by general public.
+	 *	@param  bool	(1) true (0) false - whether non-logged-in users can submit.
 	 *	@param	bool	(1) true (0) false - whether to email on all updates.
 	 *	@param	string	The address to send new entries and updates to.
-	 *	@param	int		Days before this item is considered overdue.
+	 *	@param	int	Days before this item is considered overdue.
 	 *	@param	bool	(1) trye (0) false - whether the resolution box should be shown.
 	 *	@param	string	Free-form string that project admins can place on the submit page.
 	 *	@param	string	Free-form string that project admins can place on the browse page.
 	 *	@param	int		(1) bug tracker, (2) Support Tracker, (3) Patch Tracker, (4) features (0) other.
 	 *	@return id on success, false on failure.
 	 */
 	function create($name,$description,$is_public,$allow_anon,$email_all,$email_address,
-		$due_period,$use_resolution,$submit_instructions,$browse_instructions,$datatype=0) {
+		$due_period,$use_resolution,$submit_instructions,$browse_instructions,$datatype=0,$renderer="") {
 
 		if (!forge_check_perm('tracker_admin', $this->Group->getID())) {
 			$this->setPermissionDeniedError();
@@ -204,7 +207,7 @@
 			$this->setError(_('ArtifactType: Name, Description, Due Period, and Status Timeout are required'));
 			return false;
 		}
-		
+
 		if ($email_address) {
 			$invalid_emails = validate_emails($email_address);
 			if (count($invalid_emails) > 0) {
@@ -219,9 +222,9 @@
 		$email_all = ((!$email_all) ? 0 : $email_all);
 
 		db_begin();
-		
-		$res = db_query_params ('INSERT INTO 
-			artifact_group_list 
+
+		$res = db_query_params ('INSERT INTO
+			artifact_group_list
 			(group_id,
 			name,
 			description,
@@ -233,9 +236,10 @@
 			status_timeout,
 			submit_instructions,
 			browse_instructions,
-			datatype) 
-			VALUES 
-			($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12)',
+			datatype,
+			custom_renderer)
+			VALUES
+			($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13)',
 					array ($this->Group->getID(),
 					       htmlspecialchars($name),
 					       htmlspecialchars($description),
@@ -247,10 +251,11 @@
 					       1209600,
 					       htmlspecialchars($submit_instructions),
 					       htmlspecialchars($browse_instructions),
-					       $datatype)) ;
+					       $datatype,
+					       $renderer)) ;
 
 		$id = db_insertid($res,'artifact_group_list','group_artifact_id');
-		
+
 		if (!$res || !$id) {
 			$this->setError('ArtifactType: '.db_error());
 			db_rollback();
@@ -385,7 +390,7 @@
 	function getName() {
 		return $this->data_array['name'];
 	}
-	
+
 	/**
 	 * getFormattedName - formatted name of this ArtifactType
 	 *
@@ -396,7 +401,7 @@
 		$name = strtolower($name);
 		return $name;
 	}
-	
+
 	/**
 	 * getUnixName - returns the name used by email gateway
 	 *
@@ -405,7 +410,7 @@
 	function getUnixName() {
 		return strtolower($this->Group->getUnixName()).'-'.$this->getFormattedName();
 	}
-	
+
 	/**
 	 * getReturnEmailAddress() - return the return email address for notification emails
 	 *
@@ -513,7 +518,7 @@
 				}
 				$status_id=db_result($res,0,'status_id');
 			}
-			
+
 			if ($status_id < 1 || $status_id > 4) {
 				echo "INVALID STATUS REMAP: $status_id FROM SELECTED ELEMENT: $element_id";
 				return false;
@@ -527,7 +532,7 @@
 	/**
 	 *	  getDataType - flag that is generally unused but can mark the difference between bugs, patches, etc.
 	 *
-	 *	  @return	int	The type (1) bug (2) support (3) patch (4) feature (0) other.
+	 *	  @return	int	The type (1) bug (2) support (3) patch (4) feature (5) Funktionsreferenz (0) other.
 	 */
 	function getDataType() {
 		return $this->data_array['datatype'];
@@ -578,7 +583,7 @@
 		if (!session_loggedin()) {
 			return false;
 		}
-		$result = db_query_params ('SELECT count(*) AS count FROM artifact_type_monitor 
+		$result = db_query_params ('SELECT count(*) AS count FROM artifact_type_monitor
 			WHERE user_id=$1 AND group_artifact_id=$2',
 					   array (user_getid(),
 						  $this->getID())) ;
@@ -614,7 +619,7 @@
 			$this->extra_fields["$filter"] = array();
 			if (count($types)) {
 				$res = db_query_params ('SELECT *
-				FROM artifact_extra_field_list 
+				FROM artifact_extra_field_list
 				WHERE group_artifact_id=$1
                                 AND field_type = ANY ($2)
 				ORDER BY field_type ASC',
@@ -622,7 +627,7 @@
 							       db_int_array_to_any_clause ($types))) ;
 			} else {
 				$res = db_query_params ('SELECT *
-				FROM artifact_extra_field_list 
+				FROM artifact_extra_field_list
 				WHERE group_artifact_id=$1
 				ORDER BY field_type ASC',
 							array ($this->getID())) ;
@@ -631,7 +636,7 @@
 				$this->extra_fields["$filter"][$arr['extra_field_id']] = $arr;
 			}
 		}
-			
+
 		return $this->extra_fields["$filter"];
 	}
 
@@ -694,7 +699,7 @@
 	}
 
 	/**
-	 *	getExtraFieldName - Get a box name using the box ID 
+	 *	getExtraFieldName - Get a box name using the box ID
 	 *
 	 *	@param  int 	id of an extra field.
 	 *	@return string	name of extra field.
@@ -705,8 +710,8 @@
 	}
 
 	/**
-	 *	getExtraFieldElements - List of possible admin configured 
-	 *	extra field elements. This function is used to 
+	 *	getExtraFieldElements - List of possible admin configured
+	 *	extra field elements. This function is used to
 	 *	present the boxes and choices on the main Add/Update page.
 	 *
 	 *	@param	int	id of the extra field
@@ -732,7 +737,7 @@
 //				return;
 //			}
 		}
-				
+
 		return $this->extra_field[$id];
 	}
 
@@ -817,13 +822,13 @@
 		}
 		db_begin();
 		db_query_params ('DELETE FROM artifact_extra_field_data
-			WHERE EXISTS (SELECT artifact_id FROM artifact 
+			WHERE EXISTS (SELECT artifact_id FROM artifact
 			WHERE group_artifact_id=$1
 			AND artifact.artifact_id=artifact_extra_field_data.artifact_id)',
 				 array ($this->getID())) ;
 //echo '0.1'.db_error();
 		db_query_params ('DELETE FROM artifact_extra_field_elements
-			WHERE EXISTS (SELECT extra_field_id FROM artifact_extra_field_list 
+			WHERE EXISTS (SELECT extra_field_id FROM artifact_extra_field_list
 			WHERE group_artifact_id=$1
 			AND artifact_extra_field_list.extra_field_id = artifact_extra_field_elements.extra_field_id)',
 				 array ($this->getID())) ;
@@ -832,7 +837,7 @@
 			WHERE group_artifact_id=$1',
 			array ($this->getID())) ;
 //echo '0.3'.db_error();
-		db_query_params ('DELETE FROM artifact_canned_responses 
+		db_query_params ('DELETE FROM artifact_canned_responses
 			WHERE group_artifact_id=$1',
 				 array ($this->getID())) ;
 //echo '1'.db_error();
@@ -841,25 +846,25 @@
 				 array ($this->getID())) ;
 //echo '5'.db_error();
 		db_query_params ('DELETE FROM artifact_file
-			WHERE EXISTS (SELECT artifact_id FROM artifact 
+			WHERE EXISTS (SELECT artifact_id FROM artifact
 			WHERE group_artifact_id=$1
 			AND artifact.artifact_id=artifact_file.artifact_id)',
 				 array ($this->getID())) ;
 //echo '6'.db_error();
 		db_query_params ('DELETE FROM artifact_message
-			WHERE EXISTS (SELECT artifact_id FROM artifact 
+			WHERE EXISTS (SELECT artifact_id FROM artifact
 			WHERE group_artifact_id=$1
 			AND artifact.artifact_id=artifact_message.artifact_id)',
 				 array ($this->getID())) ;
 //echo '7'.db_error();
 		db_query_params ('DELETE FROM artifact_history
-			WHERE EXISTS (SELECT artifact_id FROM artifact 
+			WHERE EXISTS (SELECT artifact_id FROM artifact
 			WHERE group_artifact_id=$1
 			AND artifact.artifact_id=artifact_history.artifact_id)',
 				 array ($this->getID())) ;
 //echo '8'.db_error();
 		db_query_params ('DELETE FROM artifact_monitor
-			WHERE EXISTS (SELECT artifact_id FROM artifact 
+			WHERE EXISTS (SELECT artifact_id FROM artifact
 			WHERE group_artifact_id=$1
 			AND artifact.artifact_id=artifact_monitor.artifact_id)',
 				 array ($this->getID())) ;
@@ -872,7 +877,7 @@
 			WHERE group_artifact_id=$1',
 				 array ($this->getID())) ;
 //echo '11'.db_error();
-		
+
 		db_commit();
 
 		$this->Group->normalizeAllRoles () ;
@@ -888,7 +893,7 @@
 	function getCannedResponses() {
 		if (!isset($this->cannedresponses_res)) {
 			$this->cannedresponses_res = db_query_params ('SELECT id,title
-				FROM artifact_canned_responses 
+				FROM artifact_canned_responses
 				WHERE group_artifact_id=$1',
 								      array ($this->getID()));
 		}
@@ -911,7 +916,7 @@
 	/**
 	 *	getStatuses - returns a result set of statuses.
 	 *
-	 *	These statuses are either the default open/closed or any number of 
+	 *	These statuses are either the default open/closed or any number of
 	 *	custom statuses that are stored in the extra fields. On insert/update
 	 *	to an artifact the status_id is remapped from the extra_field_element_id to
 	 *	the standard open/closed id.
@@ -993,10 +998,10 @@
 			}
 		}
 
-		$email_all = ((!$email_all) ? 0 : $email_all); 
-		$use_resolution = ((!$use_resolution) ? 0 : $use_resolution); 
+		$email_all = ((!$email_all) ? 0 : $email_all);
+		$use_resolution = ((!$use_resolution) ? 0 : $use_resolution);
 
-		$res = db_query_params  ('UPDATE artifact_group_list SET 
+		$res = db_query_params  ('UPDATE artifact_group_list SET
 			name=$1,
 			description=$2,
 			email_all_updates=$3,
@@ -181,19 +183,20 @@
 	 *	@param	string	Free-form string that project admins can place on the submit page.
 	 *	@param	string	Free-form string that project admins can place on the browse page.
-	 *	@param	int		(1) bug tracker, (2) Support Tracker, (3) Patch Tracker, (4) features (0) other.
-	 *	@return id on success, false on failure.
+	 *	@param	int	(1) bug tracker, (2) Support Tracker, (3) Patch Tracker, (4) features (5) Funktionsreferenz (0) other.
+	 *	@param	string	Custom renderer (defaults to "")
+	 *	@return	id on success, false on failure.
 	 */
 	function create($name,$description,$is_public,$allow_anon,$email_all,$email_address,

Modified: trunk/gforge_base/evolvisforge-5.1/src/common/tracker/ArtifactTypes.class.php
===================================================================